@@ -93,12 +93,25 @@ validateConstraintData <- function(x, attrib) {
     validateLBUB(x)
 
     if (
-      toupper(x$CONDITION) %in%
-      c("", " ", "PER TEST", "TEST")) {
+      (toupper(x$WHAT) %in%
+      c("ITEM")) &
+      (toupper(x$CONDITION) %in%
+      c("", " ", "PER TEST", "TEST"))
+    ) {
       validateLBUB(x, allow_range = FALSE)
       return()
     }
 
+    if (
+      (toupper(x$WHAT) %in%
+      c("STIMULUS", "PASSAGE", "SET", "TESTLET")) &
+      (toupper(x$CONDITION) %in%
+      c("", " ", "PER TEST", "TEST"))
+    ) {
+      validateLBUB(x, allow_range = TRUE)
+      return()
+    }
+
     if (inherits(attrib, "item_attrib")) {
       if (
         toupper(x$CONDITION) %in%
@@ -591,7 +604,7 @@ addSolutionToConstraintData <- function(x, attrib, item_idx, all_values) {
       if (x$WHAT == "ITEM") {
         x[[solution_name]] <- length(item_idx)
       }
-      if (x$WHAT %in% c("STIMULUS", "PASSAGE")) {
+      if (x$WHAT %in% c("STIMULUS", "PASSAGE", "SET", "TESTLET")) {
         x[[solution_name]] <- length(unique(attrib@data$STID[item_idx]))
       }
 
